@@ -1,10 +1,12 @@
     #include <iostream>
     #include <string>
+    #include <cstring>
+
     using namespace std;
 
     void outOfMemory()
     {
-        cout << "Memory exhausted. Program terminates." << endl;
+        cout << "Memory exhausted. Program terminates." << '\n';
         exit(1);
     }
 
